'use client'
import { Textarea } from "@nextui-org/react";
import SendMessageButton from "../buttons/SendMessageButton";
import useInputMessageStore from "@/feature/messenger/store/chat_store/useInputMessageStore";
import { createMessage } from "@/feature/messenger/services/chat/ChatService";
import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import useConversationsStore from "@/feature/messenger/store/chat_store/useConversationsStore";
import useMessagesStore from "@/feature/messenger/store/chat_store/useMessagesStore";
import { useTranslation } from "@/hooks/useTranslation";
import { useEffect, useRef } from "react";
import usePermissionChat from "@/feature/messenger/hooks/usePermissionChat";
import ModalFilesDrop from '@/feature/messenger/components/drag_and_drop/ModalFilesDrop';
import useDragAndDrop from '@/feature/messenger/hooks/useDragAndDrop';
import useDragAndDropStore from "@/feature/messenger/store/useDragAndDropStore";

export default function TextareaChat() {
    const messageInput = useInputMessageStore((state) => state.message);
    const setMessageInput = useInputMessageStore((state) => state.setMessage);
    const id_chatbot = useConfigChatStore(state => state.idChatbot);
    const selectedConversation = useConversationsStore(state => state.selectedConversation);
    const addItemListMessages = useMessagesStore(state => state.actions.addItemListMessages);
    const updateConversation = useConversationsStore(state => state.actions.updateConversation);
    const validateFocus = useMessagesStore(state => state.focus);
    const changeFocus = useMessagesStore(state => state.actions.changeFocus);
    const { trans } = useTranslation();
    const permisions = usePermissionChat();
    const inputRef = useRef<HTMLTextAreaElement>(null);
    const setFiles = useDragAndDropStore(state => state.setFiles);
    const { setModalDrop } = useDragAndDrop();

    const handleMessageChange = (message: string) => {
        setMessageInput(message);
    };
    const handleMessagePress = (e: any) => {

        if (e.key === "Enter" || e === "send" || e.type === "click") {
            const container = document.querySelector(".messages");
            if (container) {
                setTimeout(function () {
                    container.scrollBy({ top: 200, behavior: "smooth" });
                }, 310);
            }

            if (messageInput.length > 0) {
                createMessage(id_chatbot, selectedConversation.sesion, messageInput).then((res) => {
                    const response = res.data.data;
                    if (res.success === false) {
                        if (res.data.message === "WordBlockMessage") {
                            setMessageInput("");
                            const words = res.data.words;
                            //toast.error(`El mensaje contiene palabras prohibidas por el sistema (${words})`);
                            return;
                        }
                    }
                    if (response != null) {
                        addItemListMessages(response);
                        const currentSesion = selectedConversation;
                        currentSesion.conversacion = response.conversacion;
                        currentSesion.tipomensaje = response.tipomensaje;
                        currentSesion.fecha = response.fecha_sistema;
                        currentSesion.sinLeer = 0;
                        updateConversation(currentSesion);
                    }
                })
                setMessageInput("");
            }
        }
    };

    const handleLineBreak = (e: any) => {
        if (permisions.enter && e.key === "Enter") {
            e.preventDefault();
            if (messageInput.trim().length > 0) {
                handleMessagePress(e);
            } else {
                // Comportamiento original del Enter cuando el mensaje está vacío
                const newValue = e.target.value + "\n";
                handleMessageChange(newValue);
            }
        }
        // Si no es Enter, permitimos el comportamiento normal de escritura
    }

    const handlePaste = (e: React.ClipboardEvent<HTMLInputElement>) => {
        const items = e.clipboardData?.items;
        const files: File[] = [];

        if (items) {
            for (let i = 0; i < items.length; i++) {
                const item = items[i];
                if (item.kind === 'file') {
                    const file = item.getAsFile();
                    if (file) files.push(file);
                }
            }

            if (files.length > 0) {
                e.preventDefault();
                setFiles(files);
                setModalDrop(true);
            }
        }
    };

    useEffect(() => {
        if (validateFocus && inputRef.current) {
            inputRef.current.focus();
            changeFocus();
        }
    }, [validateFocus]);

    return (
        <>
            <div className="w-full">
                <Textarea
                    ref={inputRef}
                    variant="faded"
                    placeholder={trans('footer_content_chat_textarea_title')}
                    disableAnimation
                    classNames={{
                        base: "max-w-full max-h-20",
                        input: "max-h-20 w-full",
                    }}
                    value={messageInput}
                    onKeyDown={(e) => handleLineBreak(e)}
                    onChange={(e) => handleMessageChange(e.target.value)}
                    onPaste={handlePaste}
                />
            </div>
            <div>
                <SendMessageButton handleMessagePress={handleMessagePress} />
            </div>
            <ModalFilesDrop />
        </>
    )
}